/*
 * Student License - for use by students to meet course requirements and
 * perform academic research at degree granting institutions only.  Not
 * for government, commercial, or other organizational use.
 *
 * relop.h
 *
 * Code generation for function 'relop'
 *
 */

#ifndef RELOP_H
#define RELOP_H

/* Include files */
#include <cmath>
#include <math.h>
#include <stddef.h>
#include <stdlib.h>
#include <string.h>
#include "rt_defines.h"
#include "rt_nonfinite.h"
#include "rtwtypes.h"
//#include "omp.h"
#include "MAVEfast_types.h"

/* Function Declarations */
extern boolean_T relop(const creal_T a, const creal_T b);

#endif

/* End of code generation (relop.h) */
